@@ -118,8 +118,8 @@ def is_schema_valid(types, modes, names, values):
             try:
                 value = value.strip()
                 if len(value) > 23:
-                    pass
-                if len(value) > 19: # check to see if microseconds are in date
+                    datetime.strptime(value, "%Y-%m-%dT%H:%M:%S.%f+00:00")
+                elif len(value) > 19: # check to see if microseconds are in date
                     datetime.strptime(value, "%Y-%m-%d %H:%M:%S.%f")
                 else:
                     datetime.strptime(value, "%Y-%m-%d %H:%M:%S")
